PolygonSelector bounding boxes
------------------------------
`~matplotlib.widgets.PolygonSelector` now has a *draw_bounding_box* argument, which
when set to `True` will draw a bounding box around the polygon once it is
complete. The bounding box can be resized and moved, allowing the points of
the polygon to be easily resized.
